==> wls-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/wls/mapper/WlsJmsServerToWlsServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.mapper;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.mapper.MappingAgnosticStepGeneratingMapper;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsServerResourceMapping;
import com.xebialabs.deployit.plugin.wls.step.*;

import java.util.List;

public class WlsJmsServerToWlsServerMapper extends MappingAgnosticStepGeneratingMapper<WlsJmsServer, WlsServerResourceMapping, WlsServer> {

	public WlsJmsServerToWlsServerMapper(Change<Deployment> change) {
		super(change);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(WlsJmsServer jmsServer, WlsServer server, List<Step> steps) {
		if (server.isRunningVersion8())
			return;

		steps.add(new CreateWlsJmsServerFilestorePathStep(server, jmsServer));
		steps.add(new CreateWlsJmsServerStep(server, jmsServer));
		steps.add(new CreateWlsSubdeploymentStep(server.getDomain(), JmsMapperUtils.getJmsModuleName(change, server), jmsServer));
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(WlsJmsServer jmsServer, WlsServer server, List<Step> steps) {
		if (server.isRunningVersion8())
			return;

		steps.add(new DestroyWlsSubdeploymentStep(server.getDomain(), JmsMapperUtils.getJmsModuleName(change, server), jmsServer));
		steps.add(new DestroyWlsJmsServerStep(server.getDomain(), jmsServer));
	}

}

==> wls-plugin-3.0.1-sources.jar: com/xebialabs/deployit/plugin/wls/mapper/WlsJmsServerToWlsServerMapper.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.mapper;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.mapper.MappingAgnosticStepGeneratingMapper;
import com.xebialabs.deployit.plugin.wls.ci.WlsCluster;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsServerResourceMapping;
import com.xebialabs.deployit.plugin.wls.ci.WlsTarget;
import com.xebialabs.deployit.plugin.wls.step.*;

import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;

public class WlsJmsServerToWlsServerMapper extends MappingAgnosticStepGeneratingMapper<WlsJmsServer, WlsServerResourceMapping, WlsServer> {
	private final Map<WlsServer, WlsCluster> oldServerClusters;
	private final Map<WlsServer, WlsCluster> newServerClusters;
	
	public WlsJmsServerToWlsServerMapper(Change<Deployment> change, Map<WlsServer, WlsCluster> oldServerClusters,
			Map<WlsServer, WlsCluster> newServerClusters) {
		super(change);
		this.oldServerClusters = oldServerClusters;
		this.newServerClusters = newServerClusters;		
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(WlsJmsServer jmsServer, WlsServer server, List<Step> steps) {
		if (server.isRunningVersion8())
			return;

		steps.add(new CreateWlsJmsServerFilestorePathStep(server, jmsServer));
		steps.add(new CreateWlsJmsServerStep(server, jmsServer));
		steps.add(new CreateWlsSubdeploymentStep(server.getDomain(), JmsMapperUtils.getJmsModuleName(change, 
				getClusterIfApplicable(server, newServerClusters)), jmsServer));
	}
	
	private static WlsTarget getClusterIfApplicable(WlsServer server, Map<WlsServer, WlsCluster> serverClusters) {
		return (WlsTarget) ObjectUtils.defaultIfNull(serverClusters.get(server), server);		
	}
	
	@Override
	protected void generateDeletionStepsForDeletedMapping(WlsJmsServer jmsServer, WlsServer server, List<Step> steps) {
		if (server.isRunningVersion8())
			return;

		steps.add(new DestroyWlsSubdeploymentStep(server.getDomain(), JmsMapperUtils.getJmsModuleName(change, 
				getClusterIfApplicable(server, oldServerClusters)), jmsServer));
		steps.add(new DestroyWlsJmsServerStep(server.getDomain(), jmsServer));
	}

}
